average_true_range() is a generic S3 function that preserves
the input class: data.frame in, data.frame out; matrix in,
matrix out.
Handling of -values
Leading NAs are always produced for the initial lookback period
where insufficient data is available. If the input itself contains
NAs they are passed through to the underlying C routine, which
can cause the entire output to be filled with NAs. Set
na.ignore = TRUE to strip NAs before calculation and
re-insert them at their original positions in the output.
Arguments
- x
An OHLC-V series coercible to data.frame.
- cols
(formula). An optional
3-variable formula selecting columns fromxvia model.frame. Defaults to~high + low + close.- n
(integer). Lookback period (window size). A positive integer of length 1.
- na.ignore
(logical). A logical of length 1. FALSE by default. If TRUE,
NAs in the input are stripped before calculation and re-inserted at their original positions in the output.- ...
Additional parameters passed into model.frame
See also
Other Volatility Indicator:
normalized_average_true_range(),
true_range()
Examples
## load Bitcoin (BTC)
## series
data(BTC, package = "talib")
## calculate the indicator
## for Bitcoin (BTC)
output <- talib::average_true_range(BTC)
## display the results
utils::tail(output)
#> ATR
#> 2024-12-26 01:00:00 4327.272
#> 2024-12-27 01:00:00 4301.291
#> 2024-12-28 01:00:00 4027.548
#> 2024-12-29 01:00:00 3858.618
#> 2024-12-30 01:00:00 3833.282
#> 2024-12-31 01:00:00 3874.736
## visualize the indicator
## with talib::chart()
##
## see ?talib::chart or ?talib::indicator
## for more details
{
## chart OHLC-V
## series with talib::chart()
talib::chart(BTC)
## chart indicator
## with default values
talib::indicator(
talib::average_true_range
)
}