chaikin_accumulation_distribution_line() is a generic S3 function that preserves
the input class: data.frame in, data.frame out; matrix in,
matrix out.
Handling of -values
Leading NAs are always produced for the initial lookback period
where insufficient data is available. If the input itself contains
NAs they are passed through to the underlying C routine, which
can cause the entire output to be filled with NAs. Set
na.ignore = TRUE to strip NAs before calculation and
re-insert them at their original positions in the output.
Arguments
- x
An OHLC-V series coercible to data.frame.
- cols
(formula). An optional
4-variable formula selecting columns fromxvia model.frame. Defaults to~high + low + close + volume.- na.ignore
(logical). A logical of length 1. FALSE by default. If TRUE,
NAs in the input are stripped before calculation and re-inserted at their original positions in the output.- ...
Additional parameters passed into model.frame
See also
Other Volume Indicator:
chaikin_accumulation_distribution_oscillator(),
on_balance_volume(),
trading_volume()
Examples
## load Bitcoin (BTC)
## series
data(BTC, package = "talib")
## calculate the indicator
## for Bitcoin (BTC)
output <- talib::chaikin_accumulation_distribution_line(BTC)
## display the results
utils::tail(output)
#> AD
#> 2024-12-26 01:00:00 84553.27
#> 2024-12-27 01:00:00 82520.69
#> 2024-12-28 01:00:00 83098.47
#> 2024-12-29 01:00:00 82301.94
#> 2024-12-30 01:00:00 81207.80
#> 2024-12-31 01:00:00 80347.00
## visualize the indicator
## with talib::chart()
##
## see ?talib::chart or ?talib::indicator
## for more details
{
## chart OHLC-V
## series with talib::chart()
talib::chart(BTC)
## chart indicator
## with default values
talib::indicator(
talib::chaikin_accumulation_distribution_line
)
}