Skip to contents

chaikin_accumulation_distribution_oscillator() is a generic S3 function that preserves the input class: data.frame in, data.frame out; matrix in, matrix out.

Handling of -values

Leading NAs are always produced for the initial lookback period where insufficient data is available. If the input itself contains NAs they are passed through to the underlying C routine, which can cause the entire output to be filled with NAs. Set na.ignore = TRUE to strip NAs before calculation and re-insert them at their original positions in the output.

Usage

chaikin_accumulation_distribution_oscillator(
  x,
  cols,
  fast = 3,
  slow = 10,
  na.ignore = FALSE,
  ...
)

Arguments

x

An OHLC-V series coercible to data.frame.

cols

(formula). An optional 4-variable formula selecting columns from x via model.frame. Defaults to ~high + low + close + volume.

fast

(integer). Period for the fast Moving Average (MA).

slow

(integer). Period for the slow Moving Average (MA).

na.ignore

(logical). A logical of length 1. FALSE by default. If TRUE, NAs in the input are stripped before calculation and re-inserted at their original positions in the output.

...

Additional parameters passed into model.frame

Value

An object of same class and length of x:

ADOSC

double

Author

Serkan Korkmaz

Examples

## load Bitcoin (BTC)
## series
data(BTC, package = "talib")

## calculate the indicator
## for Bitcoin (BTC)
output <- talib::chaikin_accumulation_distribution_oscillator(BTC)

## display the results
utils::tail(output)
#>                           ADOSC
#> 2024-12-26 01:00:00  1179.75611
#> 2024-12-27 01:00:00   261.42433
#> 2024-12-28 01:00:00    45.81879
#> 2024-12-29 01:00:00  -299.99109
#> 2024-12-30 01:00:00  -762.32174
#> 2024-12-31 01:00:00 -1156.04783

## visualize the indicator
## with talib::chart()
##
## see ?talib::chart or ?talib::indicator
## for more details
{
 ## chart OHLC-V
 ## series with talib::chart()
 talib::chart(BTC)

 ## chart indicator
 ## with default values
 talib::indicator(
     talib::chaikin_accumulation_distribution_oscillator
 )
}