Skip to contents

extended_parabolic_stop_and_reverse() is a generic S3 function that preserves the input class: data.frame in, data.frame out; matrix in, matrix out.

Handling of -values

Leading NAs are always produced for the initial lookback period where insufficient data is available. If the input itself contains NAs they are passed through to the underlying C routine, which can cause the entire output to be filled with NAs. Set na.ignore = TRUE to strip NAs before calculation and re-insert them at their original positions in the output.

Usage

extended_parabolic_stop_and_reverse(
  x,
  cols,
  init = 0,
  offset = 0,
  init_long = 0,
  long = 0,
  max_long = 0,
  init_short = 0,
  short = 0,
  max_short = 0,
  na.ignore = FALSE,
  ...
)

Arguments

x

An OHLC-V series coercible to data.frame.

cols

(formula). An optional 2-variable formula selecting columns from x via model.frame. Defaults to ~high + low.

init

(double). Start value and direction. 0 for Auto, >0 for Long, <0 for Short.

offset

(double). Offset added/removed to initial stop on short/long reversal.

init_long

(double). Acceleration factor initial value for the Long direction.

long

(double). Acceleration factor for the Long direction.

max_long

(double). Acceleration factor maximum value for the Long direction.

init_short

(double). Acceleration factor initial value for the Short direction.

short

(double). Acceleration factor for the Short direction.

max_short

(double). Acceleration factor maximum value for the Short direction.

na.ignore

(logical). A logical of length 1. FALSE by default. If TRUE, NAs in the input are stripped before calculation and re-inserted at their original positions in the output.

...

Additional parameters passed into model.frame

Value

An object of same class and length of x:

SAREXT

double

Author

Serkan Korkmaz

Examples

## load Bitcoin (BTC)
## series
data(BTC, package = "talib")

## calculate the indicator
## for Bitcoin (BTC)
output <- talib::extended_parabolic_stop_and_reverse(BTC)

## display the results
utils::tail(output)
#>                       SAREXT
#> 2024-12-26 01:00:00 38508.01
#> 2024-12-27 01:00:00 38508.01
#> 2024-12-28 01:00:00 38508.01
#> 2024-12-29 01:00:00 38508.01
#> 2024-12-30 01:00:00 38508.01
#> 2024-12-31 01:00:00 38508.01

## visualize the indicator
## with talib::chart()
##
## see ?talib::chart or ?talib::indicator
## for more details
{
 ## chart OHLC-V
 ## series with talib::chart()
 talib::chart(BTC)

 ## chart indicator
 ## with default values
 talib::indicator(
     talib::extended_parabolic_stop_and_reverse
 )
}