Skip to contents

fast_stochastic() is a generic S3 function that preserves the input class: data.frame in, data.frame out; matrix in, matrix out.

Handling of -values

Leading NAs are always produced for the initial lookback period where insufficient data is available. If the input itself contains NAs they are passed through to the underlying C routine, which can cause the entire output to be filled with NAs. Set na.ignore = TRUE to strip NAs before calculation and re-insert them at their original positions in the output.

Usage

fast_stochastic(
  x,
  cols,
  fastk = 5,
  fastd = SMA(n = 10),
  na.ignore = FALSE,
  ...
)

Arguments

x

An OHLC-V series coercible to data.frame.

cols

(formula). An optional 3-variable formula selecting columns from x via model.frame. Defaults to ~high + low + close.

fastk

(integer). Period for the fast-k line.

fastd

(list). Period and Moving Average (MA) type for the fast-d line. SMA by default.

na.ignore

(logical). A logical of length 1. FALSE by default. If TRUE, NAs in the input are stripped before calculation and re-inserted at their original positions in the output.

...

Additional parameters passed into model.frame

Value

An object of same class and length of x:

FastK

double

FastD

double

Author

Serkan Korkmaz

Examples

## load Bitcoin (BTC)
## series
data(BTC, package = "talib")

## calculate the indicator
## for Bitcoin (BTC)
output <- talib::fast_stochastic(BTC)

## display the results
utils::tail(output)
#>                        FastK    FastD
#> 2024-12-26 01:00:00 43.96358 43.41195
#> 2024-12-27 01:00:00 23.85964 38.22778
#> 2024-12-28 01:00:00 27.44472 40.68228
#> 2024-12-29 01:00:00 10.38875 40.26691
#> 2024-12-30 01:00:00 15.37938 38.33132
#> 2024-12-31 01:00:00 34.23215 38.61201

## visualize the indicator
## with talib::chart()
##
## see ?talib::chart or ?talib::indicator
## for more details
{
 ## chart OHLC-V
 ## series with talib::chart()
 talib::chart(BTC)

 ## chart indicator
 ## with default values
 talib::indicator(
     talib::fast_stochastic
 )
}