Skip to contents

trading_volume() is a generic S3 function that preserves the input class: data.frame in, data.frame out; matrix in, matrix out.

Handling of -values

Leading NAs are always produced for the initial lookback period where insufficient data is available. If the input itself contains NAs they are passed through to the underlying C routine, which can cause the entire output to be filled with NAs. Set na.ignore = TRUE to strip NAs before calculation and re-insert them at their original positions in the output.

Usage

trading_volume(
  x,
  cols,
  ma = list(SMA(n = 7), SMA(n = 15)),
  na.ignore = FALSE,
  ...
)

Arguments

x

An OHLC-V series coercible to data.frame.

cols

(formula). An optional 3-variable formula selecting columns from x via model.frame. Defaults to ~volume + open + close.

ma

A list of MA specifications.

na.ignore

(logical). A logical of length 1. FALSE by default. If TRUE, NAs in the input are stripped before calculation and re-inserted at their original positions in the output.

...

Additional parameters passed into model.frame

Value

An object of same class and length of x:

VOLUME

double

SMA7

double

SMA15

double

Author

Serkan Korkmaz

Examples

## load Bitcoin (BTC)
## series
data(BTC, package = "talib")

## calculate the indicator
## for Bitcoin (BTC)
output <- talib::trading_volume(BTC)

## display the results
utils::tail(output)
#>                       VOLUME     SMA7    SMA15
#> 2024-12-26 01:00:00 2872.119 3554.891 3568.947
#> 2024-12-27 01:00:00 3483.965 3195.191 3553.605
#> 2024-12-28 01:00:00 1333.381 3021.574 3459.457
#> 2024-12-29 01:00:00 2131.462 2951.215 3490.991
#> 2024-12-30 01:00:00 4069.841 2891.246 3613.080
#> 2024-12-31 01:00:00 2960.960 2765.756 3519.135

## visualize the indicator
## with talib::chart()
##
## see ?talib::chart or ?talib::indicator
## for more details
{
 ## chart OHLC-V
 ## series with talib::chart()
 talib::chart(BTC)

 ## chart indicator
 ## with default values
 talib::indicator(
     talib::trading_volume
 )
}