Average Directional Movement Index Rating
Source:R/ta_ADXR.R
average_directional_movement_index_rating.Rdaverage_directional_movement_index_rating() is a generic S3 function that preserves
the input class: data.frame in, data.frame out; matrix in,
matrix out.
Handling of -values
Leading NAs are always produced for the initial lookback period
where insufficient data is available. If the input itself contains
NAs they are passed through to the underlying C routine, which
can cause the entire output to be filled with NAs. Set
na.ignore = TRUE to strip NAs before calculation and
re-insert them at their original positions in the output.
Arguments
- x
An OHLC-V series coercible to data.frame.
- cols
(formula). An optional
3-variable formula selecting columns fromxvia model.frame. Defaults to~high + low + close.- n
(integer). Lookback period (window size). A positive integer of length 1.
- na.ignore
(logical). A logical of length 1. FALSE by default. If TRUE,
NAs in the input are stripped before calculation and re-inserted at their original positions in the output.- ...
Additional parameters passed into model.frame
See also
Other Momentum Indicator:
absolute_price_oscillator(),
aroon(),
aroon_oscillator(),
average_directional_movement_index(),
balance_of_power(),
chande_momentum_oscillator(),
commodity_channel_index(),
directional_movement_index(),
extended_moving_average_convergence_divergence(),
fast_stochastic(),
fixed_moving_average_convergence_divergence(),
intraday_movement_index(),
minus_directional_indicator(),
minus_directional_movement(),
momentum(),
money_flow_index(),
moving_average_convergence_divergence(),
percentage_price_oscillator(),
plus_directional_indicator(),
plus_directional_movement(),
rate_of_change(),
ratio_of_change(),
relative_strength_index(),
stochastic(),
stochastic_relative_strength_index(),
triple_exponential_average(),
ultimate_oscillator(),
williams_oscillator()
Examples
## load Bitcoin (BTC)
## series
data(BTC, package = "talib")
## calculate the indicator
## for Bitcoin (BTC)
output <- talib::average_directional_movement_index_rating(BTC)
## display the results
utils::tail(output)
#> ADXR
#> 2024-12-26 01:00:00 34.62534
#> 2024-12-27 01:00:00 33.27814
#> 2024-12-28 01:00:00 31.97181
#> 2024-12-29 01:00:00 31.69110
#> 2024-12-30 01:00:00 31.33726
#> 2024-12-31 01:00:00 30.93191
## visualize the indicator
## with talib::chart()
##
## see ?talib::chart or ?talib::indicator
## for more details
{
## chart OHLC-V
## series with talib::chart()
talib::chart(BTC)
## chart indicator
## with default values
talib::indicator(
talib::average_directional_movement_index_rating
)
}