average_price() is a generic S3 function that preserves
the input class: data.frame in, data.frame out; matrix in,
matrix out.
Handling of -values
Leading NAs are always produced for the initial lookback period
where insufficient data is available. If the input itself contains
NAs they are passed through to the underlying C routine, which
can cause the entire output to be filled with NAs. Set
na.ignore = TRUE to strip NAs before calculation and
re-insert them at their original positions in the output.
Arguments
- x
An OHLC-V series coercible to data.frame.
- cols
(formula). An optional
4-variable formula selecting columns fromxvia model.frame. Defaults to~open + high + low + close.- na.ignore
(logical). A logical of length 1. FALSE by default. If TRUE,
NAs in the input are stripped before calculation and re-inserted at their original positions in the output.- ...
Additional parameters passed into model.frame
See also
Other Price Transform:
median_price(),
midpoint_price(),
typical_price(),
weighted_close_price()
Examples
## load Bitcoin (BTC)
## series
data(BTC, package = "talib")
## calculate the indicator
## for Bitcoin (BTC)
output <- talib::average_price(BTC)
## display the results
utils::tail(output)
#> AVGPRICE
#> 2024-12-26 01:00:00 97500.24
#> 2024-12-27 01:00:00 95138.08
#> 2024-12-28 01:00:00 94713.10
#> 2024-12-29 01:00:00 94172.46
#> 2024-12-30 01:00:00 93104.32
#> 2024-12-31 01:00:00 93507.80